def Sub_one(number):
    return number - 1